@@ -134,8 +134,11 @@ class SigV4Auth(BaseSigner):
         self.credentials = credentials
         if self.credentials is None:
             raise NoCredentialsError
-        self.now = datetime.datetime.utcnow()
-        self.timestamp = self.now.strftime('%Y%m%dT%H%M%SZ')
+        # We initialize these value here so the unit tests can have
+        # valid values.  But these will get overriden in ``add_auth``
+        # later for real requests.
+        now = datetime.datetime.utcnow()
+        self.timestamp = now.strftime('%Y%m%dT%H%M%SZ')
         self._region_name = region_name
         self._service_name = service_name
 
@@ -248,6 +251,9 @@ class SigV4Auth(BaseSigner):
         return self._sign(k_signing, string_to_sign, hex=True)
 
     def add_auth(self, request):
+        # Create a new timestamp for each signing event
+        now = datetime.datetime.utcnow()
+        self.timestamp = now.strftime('%Y%m%dT%H%M%SZ')
         # This could be a retry.  Make sure the previous
         # authorization header is removed first.
         if 'Authorization' in request.headers:
